@@ -27,13 +27,16 @@ text_set_element(__libc_atexit, _IO_cleanup);
 
 typedef void (*voidfunc) __P((void));
 
-static void _IO_register_cleanup ()
+static void
+DEFUN_VOID(_IO_register_cleanup)
 {
   atexit ((voidfunc)_IO_cleanup);
   _IO_cleanup_registration_needed = 0;
 }
 
 void (*_IO_cleanup_registration_needed)() = _IO_register_cleanup;
+#else
+void (*_IO_cleanup_registration_needed)() = NULL;
 #endif /* _G_HAVE_ATEXIT */
 
 #endif
