@@ -38,7 +38,61 @@
 #include "patchlevel.h"
 #include "ufc-crypt.h"
 
+extern ufc_long *ufc_doit  (ufc_long, ufc_long, ufc_long,
+                            ufc_long, ufc_long);
+
+/*
+ *  Prototypes
+ */
+#ifdef __STDC__
+#ifdef DEBUG
+void           pr_bits              (ufc_long *, int);
+static void    set_bits             (ufc_long, ufc_long *);
+#endif	/* DEBUG */
+STATIC void    clearmem             (char *, int);
+void init_des                       (void);
+#ifdef _UFC_32_
+STATIC void    shuffle_sb           (long32 *, ufc_long);
+#endif	/* _UFC_32_ */
+#ifdef _UFC_64_
+STATIC void    shuffle_sb           (long64 *, ufc_long);
+#endif	/* _UFC_64_ */
+STATIC void    setup_salt           (char *);
+STATIC void    ufc_mk_keytab        (char *);
+ufc_long      *ufc_dofinalperm      (ufc_long, ufc_long, ufc_long,
+                                     ufc_long);
+STATIC char   *output_conversion    (ufc_long, ufc_long, char *);
+char          *crypt                (char *, char *);
+char          *fcrypt               (char *, char *);
+void           encrypt              (char *, int);
+void           setkey               (char *);
+#else		/* ! __STDC__ */
+#ifdef DEBUG
+void           pr_bits              ();
+static void    set_bits             ();
+#endif	/* DEBUG */
+STATIC void    clearmem             ();
+void init_des                       ();
+#ifdef _UFC_32_
+TATIC  void    shuffle_sb           ();
+#endif	/* _UFC_32_ */
+#ifdef _UFC_64_
+STATIC void    shuffle_sb           ();
+#endif	/* _UFC_64_ */
+STATIC void    setup_salt           ();
+STATIC void    ufc_mk_keytab        ();
+ufc_long      *ufc_dofinalperm      ();
+STATIC char   *output_conversion    ();
+char          *crypt                ();
+char          *fcrypt               ();
+void           encrypt              ();
+void           setkey               ();
+#endif	/* __STDC__ */
+
+#if 0
+/* We don't need the warning for this: */
 static char patchlevel_str[] = PATCHLEVEL;
+#endif	/* #if 0 */
 
 /* 
  * Permutation done once on the 56 bit 
@@ -264,10 +318,17 @@ static ufc_long longmask[32] = {
 
 #ifdef DEBUG
 
+#ifdef __STDC__
+void
+pr_bits( ufc_long *a, int n)
+#else
+void
 pr_bits(a, n)
   ufc_long *a;
   int n;
-  { ufc_long i, j, t, tmp;
+#endif
+{
+    ufc_long i, j, t, tmp;
     n /= 8;
     for(i = 0; i < n; i++) {
       tmp=0;
@@ -278,20 +339,27 @@ pr_bits(a, n)
       (void)printf("%02x ",tmp);
     }
     printf(" ");
-  }
+}
 
+#ifdef __STDC__
+void
+static set_bits(ufc_long v, ufc_long *b)
+#else
+void
 static set_bits(v, b)
   ufc_long v;
   ufc_long *b;
-  { ufc_long i;
+#endif
+{
+    ufc_long i;
     *b = 0;
     for(i = 0; i < 24; i++) {
       if(v & longmask[8 + i])
 	*b |= BITMASK(i);
     }
-  }
+}
 
-#endif
+#endif	/* DEBUG */
 
 /*
  * Silly rewrite of 'bzero'. I do so
@@ -299,12 +367,19 @@ static set_bits(v, b)
  * bzero and some don't have memset.
  */
 
+#ifdef __STDC__
+STATIC void
+clearmem( char *start, int cnt)
+#else
+void
 STATIC void clearmem(start, cnt)
   char *start;
   int cnt;
-  { while(cnt--)
+#endif
+{
+   while(cnt--)
       *start++ = '\0';
-  }
+}
 
 static int initialized = 0;
 
@@ -317,8 +392,14 @@ static int initialized = 0;
  * by fcrypt users.
  */
 
+#ifdef __STDC__
+void
+init_des(void)
+#else
 void init_des()
-  { int comes_from_bit;
+#endif
+{
+    int comes_from_bit;
     int bit, sg;
     ufc_long j;
     ufc_long mask1, mask2;
@@ -478,7 +559,7 @@ void init_des()
       }
     }
     initialized++;
-  }
+}
 
 /* 
  * Process the elements of the sb table permuting the
@@ -486,23 +567,34 @@ void init_des()
  */
 
 #ifdef _UFC_32_
+#ifdef __STDC__
+STATIC void
+shuffle_sb(long32 *k, ufc_long saltbits)
+#else
 STATIC void shuffle_sb(k, saltbits)
   long32 *k;
   ufc_long saltbits;
-  { ufc_long j;
+#endif
+{
+    ufc_long j;
     long32 x;
     for(j=4096; j--;) {
       x = (k[0] ^ k[1]) & (long32)saltbits;
       *k++ ^= x;
       *k++ ^= x;
     }
-  }
-#endif
+}
+#endif	/* _UFC_32_ */
 
 #ifdef _UFC_64_
+#ifdef __STDC__
+STATIC void
+shuffle_sb(long64 *k, ufc_long saltbits)
+#else
 STATIC void shuffle_sb(k, saltbits)
   long64 *k;
   ufc_long saltbits;
+#endif
   { ufc_long j;
     long64 x;
     for(j=4096; j--;) {
@@ -510,7 +602,7 @@ STATIC void shuffle_sb(k, saltbits)
       *k++ ^= (x << 32) | x;
     }
   }
-#endif
+#endif	/* _UFC_64_ */
 
 /* 
  * Setup the unit for a new salt
@@ -521,9 +613,15 @@ static char current_salt[3] = "&&"; /* invalid value */
 static ufc_long current_saltbits = 0;
 static int direction = 0;
 
+#ifdef __STDC__
+STATIC void
+setup_salt(char *s)
+#else
 STATIC void setup_salt(s)
   char *s;
-  { ufc_long i, j, saltbits;
+#endif
+{
+    ufc_long i, j, saltbits;
 
     if(!initialized)
       init_des();
@@ -559,11 +657,17 @@ STATIC void setup_salt(s)
     shuffle_sb(ufc_sb3, current_saltbits ^ saltbits);
 
     current_saltbits = saltbits;
-  }
+}
 
+#ifdef __STDC__
+STATIC void
+ufc_mk_keytab(char *key)
+#else
 STATIC void ufc_mk_keytab(key)
   char *key;
-  { ufc_long v1, v2, *k1;
+#endif
+{
+    ufc_long v1, v2, *k1;
     int i;
 #ifdef _UFC_32_
     long32 v, *k2 = &ufc_keytab[0][0];
@@ -605,15 +709,22 @@ STATIC void ufc_mk_keytab(key)
     }
 
     direction = 0;
-  }
+}
 
 /* 
  * Undo an extra E selection and do final permutations
  */
 
-ufc_long *ufc_dofinalperm(l1, l2, r1, r2)
+#ifdef __STDC__
+ufc_long *
+ufc_dofinalperm( ufc_long l1, ufc_long l2, ufc_long r1, ufc_long r2)
+#else
+ufc_long *
+ufc_dofinalperm(l1, l2, r1, r2)
   ufc_long l1,l2,r1,r2;
-  { ufc_long v1, v2, x;
+#endif
+{
+    ufc_long v1, v2, x;
     static ufc_long ary[2];
 
     x = (l1 ^ l2) & current_saltbits; l1 ^= x; l2 ^= x;
@@ -643,17 +754,23 @@ ufc_long *ufc_dofinalperm(l1, l2, r1, r2)
 
     ary[0] = v1; ary[1] = v2;
     return ary;
-  }
+}
 
 /* 
  * crypt only: convert from 64 bit to 11 bit ASCII 
  * prefixing with the salt
  */
 
+#ifdef __STDC__
+STATIC char *
+output_conversion( ufc_long v1, ufc_long v2, char *salt)
+#else
 STATIC char *output_conversion(v1, v2, salt)
-  ufc_long v1, v2;
-  char *salt;
-  { static char outbuf[14];
+   ufc_long v1, v2;
+   char *salt;
+#endif
+{
+    static char outbuf[14];
     int i, s;
 
     outbuf[0] = salt[0];
@@ -672,17 +789,21 @@ STATIC char *output_conversion(v1, v2, salt)
     outbuf[13] = 0;
 
     return outbuf;
-  }
-
-ufc_long *ufc_doit();
+}
 
 /* 
  * UNIX crypt function
  */
    
+#ifdef __STDC__
+char *
+crypt(char *key, char *salt)
+#else
 char *crypt(key, salt)
   char *key, *salt;
-  { ufc_long *s;
+#endif
+{
+    ufc_long *s;
     char ktab[9];
 
     /*
@@ -707,18 +828,24 @@ char *crypt(key, salt)
      * And convert back to 6 bit ASCII
      */
     return output_conversion(s[0], s[1], salt);
-  }
+}
 
 /* 
  * To make fcrypt users happy.
  * They don't need to call init_des.
  */
 
+#ifdef __STDC__
+char *
+fcrypt(char *key, char *salt)
+#else
 char *fcrypt(key, salt)
   char *key;
   char *salt;
-  { return crypt(key, salt);
-  }
+#endif
+{
+   return crypt(key, salt);
+}
 
 /* 
  * UNIX encrypt function. Takes a bitvector
@@ -726,10 +853,16 @@ char *fcrypt(key, salt)
  * encrypt/decrypt according to edflag
  */
 
+#ifdef __STDC__
+void
+encrypt(char *block, int edflag)
+#else
 void encrypt(block, edflag)
   char *block;
   int edflag;
-  { ufc_long l1, l2, r1, r2, *s;
+#endif
+{
+    ufc_long l1, l2, r1, r2, *s;
     int i;
 
     /*
@@ -802,16 +935,22 @@ void encrypt(block, edflag)
       *block++ = (r1 & longmask[i]) != 0;
     }
     
-  }
+}
 
 /* 
  * UNIX setkey function. Take a 64 bit DES
  * key and setup the machinery.
  */
 
+#ifdef __STDC__
+void
+setkey(char *key)
+#else
 void setkey(key)
   char *key;
-  { int i,j;
+#endif
+{
+    int i,j;
     unsigned char c;
     unsigned char ktab[8];
 
@@ -824,9 +963,4 @@ void setkey(key)
     }
     
     ufc_mk_keytab(ktab);
-  }
-
-
-
-
-
+}
